@@ -1,15 +1,15 @@
 package App::DuplicateFilesUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-01'; # DATE
-our $DIST = 'App-DuplicateFilesUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 use Log::ger;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-08-19'; # DATE
+our $DIST = 'App-DuplicateFilesUtils'; # DIST
+our $VERSION = '0.005'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -183,7 +183,7 @@ App::DuplicateFilesUtils - CLI utilities related to duplicate files
 
 =head1 VERSION
 
-This document describes version 0.004 of App::DuplicateFilesUtils (from Perl distribution App-DuplicateFilesUtils), released on 2020-06-01.
+This document describes version 0.005 of App::DuplicateFilesUtils (from Perl distribution App-DuplicateFilesUtils), released on 2022-08-19.
 
 =head1 DESCRIPTION
 
@@ -204,7 +204,7 @@ This distributions provides the following command-line utilities:
 
 Usage:
 
- move_duplicate_files_to(%args) -> [status, msg, payload, meta]
+ move_duplicate_files_to(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Move duplicate files (except one copy) to a directory.
 
@@ -242,12 +242,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -257,7 +257,7 @@ Return value:  (any)
 
 Usage:
 
- show_duplicate_files() -> [status, msg, payload, meta]
+ show_duplicate_files() -> [$status_code, $reason, $payload, \%result_meta]
 
 Show duplicate files.
 
@@ -322,12 +322,12 @@ No arguments.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -339,6 +339,41 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Duplic
 
 Source repository is at L<https://github.com/perlancar/perl-App-DuplicateFilesUtils>.
 
+=head1 SEE ALSO
+
+L<uniq-files> and L<dupe-files> from L<App::UniqFiles>
+
+L<find-duplicate-filenames> from L<App::FindUtils>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-DuplicateFilesUtils>
@@ -347,21 +382,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<uniq-files> from L<App::UniqFiles>
-
-L<find-duplicate-filenames> from L<App::FindUtils>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
